import { CommonModule } from '@angular/common';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { NgModule, Optional, SkipSelf, InjectionToken, Injectable, Inject, defineInjectable, inject } from '@angular/core';
import { Subject } from 'rxjs';
import { map } from 'rxjs/operators';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const BASE_URL = new InjectionToken('baseUrl');
class PybLibApiModule {
    /**
     * @param {?} parentModule
     */
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('GreetingModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @param {?} config
     * @return {?}
     */
    static forRoot(config) {
        return {
            ngModule: PybLibApiModule,
            providers: [
                { provide: BASE_URL, useValue: config.baseUrl }
            ]
        };
    }
}
PybLibApiModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
            },] }
];
/** @nocollapse */
PybLibApiModule.ctorParameters = () => [
    { type: PybLibApiModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BalanceService {
    /**
     * @param {?} http
     * @param {?} baseUrl
     */
    constructor(http, baseUrl) {
        this.http = http;
        this.baseUrl = baseUrl;
    }
    /**
     * @param {?} supplierKey
     * @return {?}
     */
    getBalance(supplierKey) {
        return this.http.get(`${this.baseUrl}/sup_widget/suppliers/${supplierKey}/balance`, {});
    }
}
BalanceService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
BalanceService.ctorParameters = () => [
    { type: HttpClient },
    { type: String, decorators: [{ type: Inject, args: [BASE_URL,] }] }
];
/** @nocollapse */ BalanceService.ngInjectableDef = defineInjectable({ factory: function BalanceService_Factory() { return new BalanceService(inject(HttpClient), inject(BASE_URL)); }, token: BalanceService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CardTransactionService {
    /**
     * @param {?} http
     * @param {?} baseUrl
     */
    constructor(http, baseUrl) {
        this.http = http;
        this.baseUrl = baseUrl;
        this.transactions$ = new Subject();
    }
    /**
     * @param {?} supplierKey
     * @param {?=} params
     * @return {?}
     */
    getTransactions(supplierKey, params) {
        return this.http.post(`${this.baseUrl}/sup_widget/suppliers/${supplierKey}/pcard/get_general_report_v3`, params);
    }
}
CardTransactionService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
CardTransactionService.ctorParameters = () => [
    { type: HttpClient },
    { type: String, decorators: [{ type: Inject, args: [BASE_URL,] }] }
];
/** @nocollapse */ CardTransactionService.ngInjectableDef = defineInjectable({ factory: function CardTransactionService_Factory() { return new CardTransactionService(inject(HttpClient), inject(BASE_URL)); }, token: CardTransactionService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TransferFundsService {
    /**
     * @param {?} http
     * @param {?} baseUrl
     */
    constructor(http, baseUrl) {
        this.http = http;
        this.baseUrl = baseUrl;
    }
    /**
     * @param {?} supplierKey
     * @param {?} params
     * @return {?}
     */
    transferFunds(supplierKey, params) {
        /** @type {?} */
        const headers = new HttpHeaders({
            'content-type': 'application/json'
        });
        return this.http.post(`${this.baseUrl}/sup_widget/suppliers/${supplierKey}/payment/requests`, params, { headers });
    }
    /**
     * @param {?} availableBalance
     * @param {?} transferAmount
     * @return {?}
     */
    calcBalanceAfterTransferFunds(availableBalance, transferAmount) {
        return availableBalance - transferAmount;
    }
}
TransferFundsService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
TransferFundsService.ctorParameters = () => [
    { type: HttpClient },
    { type: String, decorators: [{ type: Inject, args: [BASE_URL,] }] }
];
/** @nocollapse */ TransferFundsService.ngInjectableDef = defineInjectable({ factory: function TransferFundsService_Factory() { return new TransferFundsService(inject(HttpClient), inject(BASE_URL)); }, token: TransferFundsService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SuppliersService {
    /**
     * @param {?} http
     * @param {?} baseUrl
     */
    constructor(http, baseUrl) {
        this.http = http;
        this.baseUrl = baseUrl;
    }
    /**
     * @return {?}
     */
    getSupplierDetails() {
        return this.http.get(`${this.baseUrl}/sup_widget/suppliers`, {}).pipe(map((/**
         * @param {?} data
         * @return {?}
         */
        (data) => data[0])));
    }
    /**
     * @param {?} supplierKey
     * @return {?}
     */
    getSupplierStatus(supplierKey) {
        /** @type {?} */
        const supplierStatus = new Subject();
        this.http.get(`${this.baseUrl}/sup_widget/suppliers/${supplierKey}/status`, {})
            .subscribe((/**
         * @param {?} data
         * @return {?}
         */
        (data) => supplierStatus.next(data)));
        return supplierStatus.asObservable();
    }
    /**
     * @param {?} supplierKey
     * @param {?=} mask
     * @return {?}
     */
    getSupplierPaymentMethods(supplierKey, mask = true) {
        /** @type {?} */
        const paymentMethods = new Subject();
        /** @type {?} */
        const params = new URLSearchParams();
        params.set('mask', mask.toString());
        this.http.get(`${this.baseUrl}/sup_widget/suppliers/${supplierKey}/payment/configs?${params}`, {})
            .subscribe((/**
         * @param {?} data
         * @return {?}
         */
        (data) => paymentMethods.next(data)));
        return paymentMethods.asObservable();
    }
}
SuppliersService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
SuppliersService.ctorParameters = () => [
    { type: HttpClient },
    { type: String, decorators: [{ type: Inject, args: [BASE_URL,] }] }
];
/** @nocollapse */ SuppliersService.ngInjectableDef = defineInjectable({ factory: function SuppliersService_Factory() { return new SuppliersService(inject(HttpClient), inject(BASE_URL)); }, token: SuppliersService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const CardTransactionsStatusEnum = {
    Held: 'Held',
    Cleared: 'Cleared',
    Declined: 'Declined',
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const PaymentMethodStatus = {
    Pending: 'pending',
    Approved: 'approved',
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const PaymentMethodType = {
    ACH: 'ACH',
    WIR: 'WIR',
    PPM: 'PPM',
    PCARD: 'PCARD',
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { PybLibApiModule, BalanceService, CardTransactionService, TransferFundsService, SuppliersService, CardTransactionsStatusEnum, PaymentMethodStatus, PaymentMethodType, BASE_URL as ɵa };

//# sourceMappingURL=pyb-lib-api.js.map